@@ -13,9 +13,8 @@ def date_rfc1123(dt):
     """Return a string representation of a date according to RFC 1123
     (HTTP/1.1).
 
-    The supplied date must be in UTC.
-
     """
+    dt = dt.astimezone(pytz.utc) # convert to UTC
     weekday = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"][dt.weekday()]
     month = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
              "Oct", "Nov", "Dec"][dt.month - 1]
